pub enum SpecifiedValue<T>{
Unspecified,
Inherit,
Specified(T),
}Expand description
Representation of a single CSS property value.
Unspecified is the Default; it means that the corresponding property is not present.
Inherit means that the property is explicitly set to inherit
from the parent element. This is useful for properties which the
SVG or CSS specs mandate that should not be inherited by default.
Specified is a value given by the SVG or CSS stylesheet. This will later be
resolved into part of a ComputedValues struct.
Variants
Implementations
Sourceimpl<T> SpecifiedValue<T>
impl<T> SpecifiedValue<T>
pub fn compute(&self, src: &T, src_values: &ComputedValues) -> T