pub fn parse_value<'i>(
prop_name: &QualName,
input: &mut Parser<'i, '_>,
parse_as: ParseAs,
) -> Result<ParsedProperty, ParseError<'i>>Expand description
Parses a value from either a style property or from an element’s attribute.
pub fn parse_value<'i>(
prop_name: &QualName,
input: &mut Parser<'i, '_>,
parse_as: ParseAs,
) -> Result<ParsedProperty, ParseError<'i>>Parses a value from either a style property or from an element’s attribute.